Agent

Struct Agent 

pub struct Agent {
    pub id: AgentID,
    pub description: String,
    pub commodity_portions: AgentCommodityPortionsMap,
    pub search_space: AgentSearchSpaceMap,
    pub decision_rule: DecisionRule,
    pub regions: IndexSet<RegionID>,
    pub objectives: AgentObjectiveMap,
}
An agent in the simulation

Fields

id: AgentID

A unique identifier for the agent.

description: String

A text description of the agent.

commodity_portions: AgentCommodityPortionsMap

The proportion of the commodity production that the agent is responsible for.

search_space: AgentSearchSpaceMap

The processes that the agent will consider investing in.

decision_rule: DecisionRule

The decision rule that the agent uses to decide investment.

regions: IndexSet<RegionID>

The regions in which this agent operates.

objectives: AgentObjectiveMap

The agent’s objectives.

Implementations

Source

impl Agent

pub fn iter_search_space( &self, region_id: &RegionID, commodity_id: &CommodityID, year: u32, ) -> impl Iterator<Item = &Rc<Process>>

Get all the processes in this agent’s search space which produce the commodity in the given region and year.

Panics

If the agent does not operate in the given region or is not responsible for the given commodity in the given year.