pub type AgentCostLimitsMap = HashMap<u32, AgentCostLimits>;Expand description
A map of cost limits for an agent, keyed by year
Aliased Type
pub struct AgentCostLimitsMap { /* private fields */ }pub type AgentCostLimitsMap = HashMap<u32, AgentCostLimits>;A map of cost limits for an agent, keyed by year
pub struct AgentCostLimitsMap { /* private fields */ }