AssetCapacity

Enum AssetCapacity 

pub enum AssetCapacity {
    Continuous(Capacity),
    Discrete(u32, Capacity),
}
Capacity of an asset, which may be continuous or a discrete number of indivisible units

Variants



Continuous(Capacity)

Continuous capacity



Discrete(u32, Capacity)

Discrete capacity represented by a number of indivisible units Stores: (number of units, unit size)

Implementations

Source

impl AssetCapacity

pub fn min(self, other: AssetCapacity) -> AssetCapacity

Return the smaller of self or other.

Panics

Panics if the comparison is not meaningful. This happens if either AssetCapacity contains a NaN value, one is discrete and the other continuous or if both are discrete and the unit size differs.

Source

impl AssetCapacity

fn check_same_unit_size(size1: Capacity, size2: Capacity)

Validates that two discrete capacities have the same unit size.

pub fn from_capacity(capacity: Capacity, unit_size: Option<Capacity>) -> Self

Create an AssetCapacity from a total capacity and optional unit size

If a unit size is provided, the capacity is represented as a discrete number of units, calculated as the ceiling of (capacity / unit_size). If no unit size is provided, the capacity is represented as continuous.

pub fn from_capacity_floor( capacity: Capacity, unit_size: Option<Capacity>, ) -> Self

Create an AssetCapacity from a total capacity and optional unit size

If a unit size is provided, the capacity is represented as a discrete number of units, calculated as the floor of (capacity / unit_size). If no unit size is provided, the capacity is represented as continuous.

pub fn total_capacity(&self) -> Capacity

Returns the total capacity represented by this AssetCapacity.

pub fn n_units(&self) -> Option<u32>

Returns the number of units if this is a discrete capacity, or None if continuous.

pub fn assert_same_type(&self, other: AssetCapacity)

Asserts that both capacities are the same type (both continuous or both discrete).