AssetCmp

Enum AssetCmp 

enum AssetCmp<'a> {
    WithID(AssetID),
    WithoutID((&'a ProcessID, &'a RegionID, u32, Option<&'a AgentID>, Option<AssetGroupID>)),
}
A data structure representing the fields of an Asset that should be used for comparisons.

For assets that have an ID (i.e. have been commissioned at some point), we can compare based on the ID. Otherwise, we fall back on comparing other properties. The combination of these properties should be unique within the simulation (e.g. for assets being input into dispatch).

Variants



WithID(AssetID)



WithoutID((&'a ProcessID, &'a RegionID, u32, Option<&'a AgentID>, Option<AssetGroupID>))