pub enum AssetState {
Commissioned {
id: AssetID,
agent_id: AgentID,
mothballed_year: Option<u32>,
parent: Option<AssetRef>,
},
Decommissioned {
id: AssetID,
agent_id: AgentID,
decommission_year: u32,
},
Future {
agent_id: AgentID,
},
Selected {
agent_id: AgentID,
},
Parent {
agent_id: AgentID,
group_id: AssetGroupID,
},
Candidate,
}Expand description
The state of an asset
New assets are created as either Future or Candidate assets. Future assets (which are
specified in the input data) have a fixed capacity and capital costs already accounted for,
whereas Candidate assets capital costs are not yet accounted for, and their capacity is
determined by the investment algorithm.
Future and Candidate assets can be converted to Commissioned assets by calling
the commission method (or via pool operations that commission future/selected assets).
Commissioned assets can be decommissioned by calling decommission.
Variants
Commissioned
The asset has been commissioned
Fields
Decommissioned
The asset has been decommissioned
Fields
Future
The asset is planned for commissioning in the future
Selected
The asset has been selected for investment, but not yet confirmed
Parent
The asset is a parent of other assets.
Parents are used for grouping (commissioned) divided assets, which can be used as an optimisation.
Fields
group_id: AssetGroupIDID of the asset group
Candidate
The asset is a candidate for investment but has not yet been selected by an agent