AssetPool

Struct AssetPool 

pub struct AssetPool {
    assets: Vec<AssetRef>,
    next_id: u32,
    next_group_id: u32,
}
The active pool of super::Assets

Fields

assets: Vec<AssetRef>

The pool of active assets, sorted by ID

next_id: u32

Next available asset ID number

next_group_id: u32

Next available group ID number

Implementations

Source

impl AssetPool

pub fn new() -> Self

Create a new empty AssetPool

pub fn as_slice(&self) -> &[AssetRef]

Get the active pool as a slice of AssetRefs

pub fn commission_new( &mut self, year: u32, user_assets: &mut Vec<AssetRef>, ) -> &[AssetRef]

Commission new assets for the specified milestone year from the input data.

Returns the newly commissioned assets (children, for divisible assets).

fn commission(&mut self, asset: AssetRef, reason: &str)

Commission the specified asset or, if divisible, its children

pub fn decommission_old(&mut self, year: u32)

Decommission old assets for the specified milestone year

pub fn decommission_mothballed(&mut self, year: u32, mothball_years: u32)

Decommission mothballed assets if mothballed long enough

pub fn mothball_unretained<I>(&mut self, assets: I, year: u32)
where I: IntoIterator<Item = AssetRef>,

Mothball the specified assets if they are no longer in the active pool and put them back again.

Arguments
  • assets - Assets to possibly mothball
  • year - Mothball year
Panics

Panics if any of the provided assets was never commissioned.

pub fn get(&self, id: AssetID) -> Option<&AssetRef>

Get an asset with the specified ID.

Returns

An AssetRef if found, else None. The asset may not be found if it has already been decommissioned.

pub fn iter(&self) -> Iter<'_, AssetRef>

Iterate over active assets

pub fn take(&mut self) -> Vec<AssetRef>

Return current active pool and clear

pub fn extend<I>(&mut self, assets: I) -> &[AssetRef]
where I: IntoIterator<Item = AssetRef>,

Extend the active pool with Commissioned or Selected assets.

Returns the newly commissioned assets (those that were in Selected state on entry).