fn init_investment_graph_for_year(
graphs: &IndexMap<(RegionID, u32), CommoditiesGraph>,
year: u32,
commodities: &CommodityMap,
) -> Graph<MarketSet, GraphEdge, Directed>Expand description
Initialise an InvestmentGraph for the given year from a set of CommodityGraphs
Commodity graphs for each region are first filtered to only include SVD/SED commodities. Each
commodity node is then added to a global investment graph as an MarketSet::Single, with
edges preserved from the original commodity graphs.