add_entry_to_search_space_map

Function add_entry_to_search_space_map 

fn add_entry_to_search_space_map(
    entry: &SearchSpaceEntry,
    agents: &AgentMap,
    processes: &ProcessMap,
    commodity_ids: &HashSet<CommodityID>,
    milestone_years: &[u32],
    producers: &HashMap<(CommodityID, RegionID, u32), Rc<Vec<Rc<Process>>>>,
    map: &mut HashMap<AgentID, AgentSearchSpaceMap>,
) -> Result<()>
Add a new entry to the search space map.

Returns

Returns an error if the entry is invalid or there is already an existing entry for the same key in map.