pub fn is_sorted_and_unique_with<T, I, F>(iter: I, less_than: F) -> boolExpand description
Check whether an iterator contains values that are sorted and unique, comparing with a custom function
pub fn is_sorted_and_unique_with<T, I, F>(iter: I, less_than: F) -> boolCheck whether an iterator contains values that are sorted and unique, comparing with a custom function