pub fn read_process_availabilities(
model_dir: &Path,
processes: &ProcessMap,
time_slice_info: &TimeSliceInfo,
) -> Result<HashMap<ProcessID, ProcessActivityLimitsMap>>Expand description
Read the process availabilities CSV file.
This file contains information about the availability of processes over the course of a year as a proportion of their maximum capacity.
Arguments
model_dir- Folder containing model configuration filesprocesses- Map of processestime_slice_info- Information about seasons and times of day
Returns
A HashMap with process IDs as the keys and ProcessActivityLimitsMaps as the values or an
error.