fn validate_output_flows_units(
flows_map: &HashMap<ProcessID, ProcessFlowsMap>,
) -> Result<()>Expand description
Validates that all SED/SVD outputs from each process have consistent units.
For processes with multiple SED/SVD outputs, the annual fixed costs are distributed proportionally based on flow coefficients. This only makes sense if all outputs share the same units.