struct ProcessInvestmentConstraintRaw {
process_id: String,
regions: String,
commission_years: String,
addition_limit: Option<CapacityPerYear>,
capacity_growth_limit: Option<Dimensionless>,
growth_seed: Option<Dimensionless>,
total_capacity_limit: Option<Capacity>,
}Expand description
Represents a row of the process investment constraints CSV file
Fields
process_id: Stringregions: Stringcommission_years: Stringaddition_limit: Option<CapacityPerYear>capacity_growth_limit: Option<Dimensionless>growth_seed: Option<Dimensionless>total_capacity_limit: Option<Capacity>Implementations
Sourceimpl ProcessInvestmentConstraintRaw
impl ProcessInvestmentConstraintRaw
Sourcefn validate(&self) -> Result<()>
fn validate(&self) -> Result<()>
Validate the constraint record for logical consistency and required fields
Sourcefn validate_constraint_value<T: UnitType>(
constraint: T,
constraint_name: &str,
) -> Result<()>
fn validate_constraint_value<T: UnitType>( constraint: T, constraint_name: &str, ) -> Result<()>
Check whether the limit is finite, otherwise return an error
Sourcefn validate_constraints_combination(&self) -> Result<()>
fn validate_constraints_combination(&self) -> Result<()>
Check that the combination of constraints is valid