partition

Function partition 

pub fn partition<'a>(s: &'a str, delimiter: &str) -> Option<(&'a str, &'a str)>
Try to divide a string into two parts at the specified delimiter.

Returns

  • None if delimiter is not present
  • Some tuple of the two strings if it is