macro_rules! docs_url {
() => { ... };
($suffix:literal) => { ... };
}Expand description
A macro to get a url to the most recent version of the documentation
macro_rules! docs_url {
() => { ... };
($suffix:literal) => { ... };
}A macro to get a url to the most recent version of the documentation