check_highs_options

Function check_highs_options 

fn check_highs_options(
    dangerous_options_enabled: bool,
    highs: &HighsOptions,
) -> Result<()>
Check the custom HiGHS options are valid.

Note that we cannot know whether the options specified exist and are of the correct type until we attempt to use them. We could check for types that are never valid (e.g. an array), but as we’re checking later anyway, we don’t bother.