dangerous_model_options_enabled

Function dangerous_model_options_enabled 

pub fn dangerous_model_options_enabled() -> bool
Whether potentially dangerous model options were enabled by the loaded config.

Panics

Panics if the global flag has not been set yet (the flag should be set by ModelParameters::from_path during program initialisation).