DataWriter

Struct DataWriter 

pub struct DataWriter {
    assets: Writer<File>,
    asset_capacities: Writer<File>,
    flows: Writer<File>,
    prices: Writer<File>,
    debug: Option<DebugDataWriter>,
}
An object for writing output data to file

Fields

assets: Writer<File>asset_capacities: Writer<File>flows: Writer<File>prices: Writer<File>debug: Option<DebugDataWriter>

Implementations

Source

impl DataWriter

pub fn create( output_path: &Path, model_path: &Path, save_debug_info: bool, ) -> Result<Self>

Open CSV files to write output data to

Arguments
  • output_path - Folder where files will be saved
  • model_path - Path to input model
  • save_debug_info - Whether to include extra CSV files for debugging model
pub fn write_dispatch_debug_info( &mut self, milestone_year: u32, run_description: &str, solution: &Solution<'_>, ) -> Result<()>

Write debug info about the dispatch optimisation

pub fn write_appraisal_debug_info( &mut self, milestone_year: u32, run_description: &str, appraisal_results: &[AppraisalOutput], demand: &IndexMap<TimeSliceID, Flow>, ) -> Result<()>

Write debug info about the investment appraisal

pub fn write_assets<'a, I>(&mut self, assets: I) -> Result<()>
where I: Iterator<Item = &'a AssetRef>,

Append newly commissioned asset definitions to the assets CSV file.

For divisible asset groups, a single row is emitted per group (using the parent asset’s metadata).

pub fn write_asset_capacities<'a, I>( &mut self, milestone_year: u32, assets: I, ) -> Result<()>
where I: Iterator<Item = &'a AssetRef>,

Write asset capacities for the current milestone year to a CSV file.

This file is appended to on each invocation. For divisible asset groups, a single row is emitted per group with the total capacity.

pub fn write_flows( &mut self, milestone_year: u32, flow_map: &FlowMap, ) -> Result<()>

Write commodity flows to a CSV file

pub fn write_prices( &mut self, milestone_year: u32, prices: &CommodityPrices, ) -> Result<()>

Write commodity prices to a CSV file

pub fn flush(&mut self) -> Result<()>

Flush the underlying streams

pub fn set_debug_context(&mut self, context: String)

Add context to the debug writer

pub fn clear_debug_context(&mut self)

Clear context from the debug writer