pub struct Settings {
pub log_level: String,
pub overwrite: bool,
pub debug_model: bool,
}Expand description
Program settings from config file
NOTE: If you add or change a field in this struct, you must also update the schema in
schemas/settings.yaml.
Fields
log_level: StringThe default program log level
overwrite: boolWhether to overwrite output files by default
debug_model: boolWhether to write additional information to CSV files
Implementations
Sourceimpl Settings
impl Settings
Sourcepub fn load() -> Result<Settings>
pub fn load() -> Result<Settings>
Read the contents of a settings file from the model directory.
If the file is not present, default values for settings will be used
Returns
The program settings as a Settings struct or an error if the file is invalid
Sourcefn load_from_path(file_path: &Path) -> Result<Settings>
fn load_from_path(file_path: &Path) -> Result<Settings>
Read from the specified path, returning
Sourcepub fn default_file_contents() -> String
pub fn default_file_contents() -> String
The contents of the default settings file