pub struct ObjectiveCoefficients {
pub capacity_coefficient: MoneyPerCapacity,
pub activity_coefficients: IndexMap<TimeSliceID, MoneyPerActivity>,
pub unmet_demand_coefficient: MoneyPerFlow,
}Expand description
Map storing cost coefficients for an asset.
These are calculated according to the objective type of the agent owning the asset. Map storing coefficients for each variable
Fields
capacity_coefficient: MoneyPerCapacityCost per unit of capacity
activity_coefficients: IndexMap<TimeSliceID, MoneyPerActivity>Cost per unit of activity in each time slice
unmet_demand_coefficient: MoneyPerFlowUnmet demand coefficient