pub fn annual_fixed_cost(asset: &AssetRef) -> MoneyPerCapacityExpand description
Calculates the annual fixed costs per unit of capacity for an asset.
The behaviour depends on whether the asset is commissioned or a candidate:
- For a commissioned asset, this only includes operating costs.
- For a candidate asset, this includes both operating and capital costs.
The return value is the annualised fixed cost expressed as MoneyPerCapacity.
If asset.state() is not Commissioned or Candidate this function will panic.