pub fn appraise_investment(
model: &Model,
asset: &AssetRef,
max_capacity: Option<AssetCapacity>,
commodity: &Commodity,
objective_type: &ObjectiveType,
coefficients: &Rc<ObjectiveCoefficients>,
demand: &IndexMap<TimeSliceID, Flow>,
) -> Result<AppraisalOutput>Expand description
Appraise the given investment with the specified objective type.
Returns
The AppraisalOutput produced by the selected appraisal method. The metric field is
comparable with other appraisals of the same type (npv/lcox).