count_equal_and_best_appraisal_outputs

Function count_equal_and_best_appraisal_outputs 

pub fn count_equal_and_best_appraisal_outputs(
    outputs: &[AppraisalOutput],
) -> usize
Counts the number of top appraisal outputs in a sorted slice that are indistinguishable by both metric and fallback ordering. Excludes the first element from the count.