fn add_activity_vars(
problem: &mut RowProblem,
cost_coefficients: &ObjectiveCoefficients,
) -> IndexMap<TimeSliceID, Col>Expand description
Adds activity variables to the problem, one per time slice.
Returns a map from time slice to the corresponding decision variable.