pub fn calculate_candidate_asset_capacity_scale(
asset: &Asset,
commodity: &Commodity,
demand: &DemandMap,
) -> CapacityExpand description
Calculates a characteristic capacity scale for a candidate asset.
The returned value is the capacity that would satisfy the total annual demand assuming the asset operates at its maximum annual activity for the entire year. It ignores finer-grained activity constraints and temporal variations in demand.
This value is later scaled by capacity_limit_factor to set capacities for candidate assets in
each round of investments.
If the asset has zero maximum annual supply, zero capacity is returned. This indicates that the
asset is non-feasible, and will be excluded from consideration by select_best_assets.