calculate_investment_limits_for_candidates

Function calculate_investment_limits_for_candidates 

fn calculate_investment_limits_for_candidates(
    opt_assets: &[AssetRef],
    commodity_portion: Dimensionless,
) -> HashMap<AssetRef, AssetCapacity>
Calculate investment limits for an agent’s candidate assets in a given year

Investment limits are based on demand for the commodity (capacity cannot exceed that needed to meet demand), and any annual addition limits specified by the process (scaled according to the agent’s portion of the commodity demand and the number of years elapsed since the previous milestone year).