fn is_any_remaining_demand(
demand: &IndexMap<TimeSliceID, Flow>,
absolute_tolerance: Flow,
) -> boolExpand description
Check whether there is any remaining demand that is unmet in any time slice
fn is_any_remaining_demand(
demand: &IndexMap<TimeSliceID, Flow>,
absolute_tolerance: Flow,
) -> boolCheck whether there is any remaining demand that is unmet in any time slice