pub type AllDemandMap = IndexMap<(CommodityID, RegionID, TimeSliceID), Flow>;Expand description
Demand for a given combination of commodity, region and time slice
Aliased Type
pub struct AllDemandMap { /* private fields */ }pub type AllDemandMap = IndexMap<(CommodityID, RegionID, TimeSliceID), Flow>;Demand for a given combination of commodity, region and time slice
pub struct AllDemandMap { /* private fields */ }