type DemandMap = IndexMap<TimeSliceID, Flow>;Expand description
A map of demand across time slices for a specific commodity and region
Aliased Type
struct DemandMap { /* private fields */ }type DemandMap = IndexMap<TimeSliceID, Flow>;A map of demand across time slices for a specific commodity and region
struct DemandMap { /* private fields */ }