collect_investment_limits_for_candidates

Function collect_investment_limits_for_candidates 

pub fn collect_investment_limits_for_candidates(
    opt_assets: &[AssetRef],
    commodity_portion: Dimensionless,
) -> HashMap<AssetRef, AssetCapacity>
Investment limits are based on any annual addition limits specified by the process, scaled according to the agent’s portion of the commodity demand and the number of years elapsed since the previous milestone year.