get_candidate_assets

Function get_candidate_assets 

fn get_candidate_assets<'a>(
    demand: &'a DemandMap,
    agent: &'a Agent,
    region_id: &'a RegionID,
    commodity: &'a Commodity,
    year: u32,
    capacity_limit_factor: Dimensionless,
) -> impl Iterator<Item = AssetRef> + 'a
Get candidate assets which produce a particular commodity for a given agent

Each candidate is assigned a capacity. For divisible assets, the capacity is set to 1 unit. For indivisible assets, a capacity is calculated based on the total demand for the commodity and the asset’s maximum annual production per unit capacity (see calculate_candidate_asset_capacity_scale), then multiplied by capacity_limit_factor.