pub fn add_asset_constraints<'a, I>(
problem: &mut RowProblem,
variables: &VariableMap,
model: &'a Model,
assets: &I,
commodities: &'a [CommodityID],
year: u32,
) -> ConstraintKeysExpand description
Add asset-level constraints
Note: the ordering of constraints is important, as the dual values of the constraints must later be retrieved to calculate commodity prices.
Arguments
problem- The optimisation problemvariables- The variables in the problemmodel- The modelassets- The asset poolcommodities- The subset of commodities to apply constraints toyear- Current milestone year
Returns
Keys for the different constraints.