Solution

Struct Solution 

pub struct Solution<'a> {
    solution: Solution,
    variables: VariableMap,
    time_slice_info: &'a TimeSliceInfo,
    constraint_keys: ConstraintKeys,
    flow_map: Cell<Option<FlowMap>>,
    pub objective_value: Money,
}
The solution to the dispatch optimisation problem

Fields

solution: Solutionvariables: VariableMaptime_slice_info: &'a TimeSliceInfoconstraint_keys: ConstraintKeysflow_map: Cell<Option<FlowMap>>objective_value: Money

The objective value for the solution

Implementations

Source

impl Solution<'_>

pub fn create_flow_map(&self) -> FlowMap

Create a map of commodity flows for each asset’s coeffs at every time slice.

Note: The flow map is actually already created and is taken from self when this method is called (hence it can only be called once). The reason for this is because we need to convert back from parent assets to child assets. We can remove this hack once we have updated all the users of this interface to be able to handle parent assets correctly.

pub fn iter_activity( &self, ) -> impl Iterator<Item = (&AssetRef, &TimeSliceID, Activity)>

Activity for all assets (existing and candidate, if present)

pub fn iter_activity_for_existing( &self, ) -> impl Iterator<Item = (&AssetRef, &TimeSliceID, Activity)>

Activity for each existing asset

pub fn iter_activity_keys_for_existing( &self, ) -> impl Iterator<Item = (&AssetRef, &TimeSliceID)>

Iterate over the keys for activity for each existing asset

pub fn iter_activity_for_candidates( &self, ) -> impl Iterator<Item = (&AssetRef, &TimeSliceID, Activity)>

Activity for each candidate asset

pub fn iter_activity_keys_for_candidates( &self, ) -> impl Iterator<Item = (&AssetRef, &TimeSliceID)>

Iterate over the keys for activity for each candidate asset

pub fn iter_unmet_demand( &self, ) -> impl Iterator<Item = (&CommodityID, &RegionID, &TimeSliceID, Flow)>

Iterate over unmet demand

pub fn iter_capacity(&self) -> impl Iterator<Item = (&AssetRef, AssetCapacity)>

Iterate over capacity values

Will return AssetCapacity::Continuous or AssetCapacity::Discrete depending on whether the asset has a defined unit size.

pub fn iter_commodity_balance_duals( &self, ) -> impl Iterator<Item = (&CommodityID, &RegionID, &TimeSliceID, MoneyPerFlow)>

Keys and dual values for commodity balance constraints.

pub fn iter_activity_duals( &self, ) -> impl Iterator<Item = (&AssetRef, &TimeSliceID, MoneyPerActivity)>

Keys and dual values for activity constraints.

Note: if there are any flexible capacity assets, these will have two duals with identical keys, and there will be no way to distinguish between them in the resulting iterator. Recommended for now only to use this function when there are no flexible capacity assets.

Also note: this excludes seasonal and annual constraints. Recommended for now not to use this for models that include seasonal or annual availability constraints.

pub fn iter_column_duals( &self, ) -> impl Iterator<Item = (&AssetRef, &TimeSliceID, MoneyPerActivity)>

Keys and values for column duals.