pub struct CommodityPrices(IndexMap<(CommodityID, RegionID, TimeSliceID), MoneyPerFlow>);Expand description
A map relating commodity ID + region + time slice to current price (endogenous)
Tuple Fields
0: IndexMap<(CommodityID, RegionID, TimeSliceID), MoneyPerFlow>Implementations
Sourceimpl CommodityPrices
impl CommodityPrices
Sourcepub fn insert(
&mut self,
commodity_id: &CommodityID,
region_id: &RegionID,
time_slice: &TimeSliceID,
price: MoneyPerFlow,
)
pub fn insert( &mut self, commodity_id: &CommodityID, region_id: &RegionID, time_slice: &TimeSliceID, price: MoneyPerFlow, )
Insert/update a price for the given commodity, region and time slice.
Sourcefn extend_selection_prices(
&mut self,
group_prices: &IndexMap<(CommodityID, RegionID, TimeSliceSelection), MoneyPerFlow>,
time_slice_info: &TimeSliceInfo,
)
fn extend_selection_prices( &mut self, group_prices: &IndexMap<(CommodityID, RegionID, TimeSliceSelection), MoneyPerFlow>, time_slice_info: &TimeSliceInfo, )
Extend/update this map by applying each selection-level price to all time slices contained in that selection.
Sourcepub fn iter(
&self,
) -> impl Iterator<Item = (&CommodityID, &RegionID, &TimeSliceID, MoneyPerFlow)>
pub fn iter( &self, ) -> impl Iterator<Item = (&CommodityID, &RegionID, &TimeSliceID, MoneyPerFlow)>
Iterate over the map.
Returns
An iterator of tuples containing commodity ID, region ID, time slice and price.
Sourcepub fn get(
&self,
commodity_id: &CommodityID,
region_id: &RegionID,
time_slice: &TimeSliceID,
) -> Option<MoneyPerFlow>
pub fn get( &self, commodity_id: &CommodityID, region_id: &RegionID, time_slice: &TimeSliceID, ) -> Option<MoneyPerFlow>
Get the price for the specified commodity for a given region and time slice
Sourcepub fn keys(
&self,
) -> Keys<'_, (CommodityID, RegionID, TimeSliceID), MoneyPerFlow>
pub fn keys( &self, ) -> Keys<'_, (CommodityID, RegionID, TimeSliceID), MoneyPerFlow>
Iterate over the price map’s keys
Sourcefn time_slice_weighted_averages(
&self,
time_slice_info: &TimeSliceInfo,
) -> HashMap<(CommodityID, RegionID), MoneyPerFlow>
fn time_slice_weighted_averages( &self, time_slice_info: &TimeSliceInfo, ) -> HashMap<(CommodityID, RegionID), MoneyPerFlow>
Calculate time slice-weighted average prices for each commodity-region pair
This method aggregates prices across time slices by weighting each price by the duration of its time slice, providing a more representative annual average.
Note: this assumes that all time slices are present for each commodity-region pair, and that all time slice lengths sum to 1. This is not checked by this method.
Sourcepub fn within_tolerance_weighted(
&self,
other: &Self,
tolerance: Dimensionless,
time_slice_info: &TimeSliceInfo,
) -> bool
pub fn within_tolerance_weighted( &self, other: &Self, tolerance: Dimensionless, time_slice_info: &TimeSliceInfo, ) -> bool
Check if time slice-weighted average prices are within relative tolerance of another price set.
This method calculates time slice-weighted average prices for each commodity-region pair and compares them. Both objects must have exactly the same set of commodity-region pairs, otherwise it will panic.
Additionally, this method assumes that all time slices are present for each commodity-region pair, and that all time slice lengths sum to 1. This is not checked by this method.