struct WeightedAverageBackupAccumulator<W: UnitType> {
primary: WeightedAverageAccumulator<W>,
backup: WeightedAverageAccumulator<W>,
}Expand description
Weighted average accumulator with a backup weighting path for MoneyPerFlow prices.
Fields
primary: WeightedAverageAccumulator<W>Primary weighted average path.
backup: WeightedAverageAccumulator<W>Backup weighted average path.
Implementations
Sourceimpl<W: UnitType> WeightedAverageBackupAccumulator<W>
impl<W: UnitType> WeightedAverageBackupAccumulator<W>
Sourcefn add(&mut self, value: MoneyPerFlow, weight: W, backup_weight: W)
fn add(&mut self, value: MoneyPerFlow, weight: W, backup_weight: W)
Add a weighted value to the accumulator with a backup weight.
Sourcefn finalise(self) -> Option<MoneyPerFlow>
fn finalise(self) -> Option<MoneyPerFlow>
Solve the weighted average, falling back to backup weights if needed.
Returns None if both denominators are zero (or close to zero).