pub struct GenericTimer<C: TimeContext = GenericContext> {
start: Instant,
_context: PhantomData<C>,
}Expand description
Generic timing implementation shared by all timing contexts
Fields
start: Instant_context: PhantomData<C>Trait Implementations
Sourceimpl<T, C: TimeContext> SyncWrapContext<T> for GenericTimer<C>
impl<T, C: TimeContext> SyncWrapContext<T> for GenericTimer<C>
Sourcefn after(self, caller_context: &CallerContext, _result: &T)
fn after(self, caller_context: &CallerContext, _result: &T)
Execute the code after the execution of the wrapped body, it provides also the result of the wrapped body Read more
fn before(&self, caller_context: &CallerContext)
fn before(&self, caller_context: &CallerContext)
Execute the code before the execution of the wrapped body Read more