pub enum AssetState {
Commissioned {
id: AssetID,
agent_id: AgentID,
mothball_events: VecDeque<MothballEvent>,
},
Ready {
agent_id: AgentID,
commission_reason: &'static str,
},
Candidate,
}Expand description
The state of an asset
New assets are created as either Ready or Candidate assets. Ready assets from the input
data have a fixed capacity and capital costs already accounted for, whereas Candidate assets’
capital costs are not yet accounted for, and their capacity is determined by the investment
algorithm.
Ready assets can be converted to Commissioned assets by calling the commission method (or
via pool operations that commission ready assets).
Variants
Commissioned
The asset has been commissioned
Fields
mothball_events: VecDeque<MothballEvent>Years in which all of some of the asset was mothballed.
Invariants: This must be sorted by year with older years first and the total number of units must not exceed the total for this asset.
Ready
The asset is ready for investment, but not yet confirmed
Fields
Candidate
The asset is a candidate for investment but has not yet been selected by an agent