AssetRef

Struct AssetRef 

pub struct AssetRef(Rc<Asset>);
A wrapper containing a reference-counted Asset.

AssetRef implements equality, ordering, and hashing using an AssetID, if available, but otherwise using a combination of other fields which should be unique at all the relevant points in the simulation.

Tuple Fields

0: Rc<Asset>

Implementations

Source

impl AssetRef

pub fn make_mut(&mut self) -> &mut Asset

Make a mutable reference to the underlying Asset

fn get_asset_cmp(&self) -> AssetCmp<'_>

Get a representation of this AssetRef that can be used for comparisons

pub fn with_subset_of_units(self, new_num_units: u32) -> Self

Get an AssetRef representing a subset of this asset’s units.

For non-divisible assets, new_num_units must be one. If some of the asset’s units are mothballed, these are discarded before non-mothballed units. For example, if an asset has seven units of which four are mothballed and we are reducing the number of units to four, the new asset will have one mothballed unit.

Panics

Panics if new_num_units is zero or exceeds the total capacity of this asset.

fn decommission(self, reason: &str)

Decommission this asset

fn with_decommission_mothballed( self, year: u32, mothball_years: u32, ) -> Option<Self>

Decommission any units that were mothballed at least mothball_years ago.

If the asset still has some units remaining, it is returned, else None.

pub fn with_mothballed_units(self, num_units: u32, year: Option<u32>) -> Self

Return a new AssetRef with the specified number of units mothballed.

If num_units equals the number of already mothballed units, the original asset is returned. If additional units may be mothballed, a value must be provided for year.

Panics

Panics if attempting to mothball more units than the asset represents or if attempting to change the number of mothballed units for a non-commissioned asset.

pub fn with_no_mothballed_units(self) -> Self

Returns a new AssetRef with no mothballed units.

If the asset has no mothballed units, the original asset is returned.