pub fn lcox(
capacity: Capacity,
annual_fixed_cost: MoneyPerCapacity,
activity: &IndexMap<TimeSliceID, Activity>,
activity_costs: &IndexMap<TimeSliceID, MoneyPerActivity>,
) -> Option<MoneyPerActivity>Expand description
Calculates annual LCOX based on capacity and activity.
It should be called with activity costs that EXCLUDE the commodity of interest.
If the total activity is zero, then it returns None, otherwise Some LCOX value.