fn read_csv_id_file<T, I: ID>(file_path: &Path) -> Result<IndexMap<I, T>>where
T: HasID<I> + DeserializeOwned,Expand description
Read a CSV file of items with IDs.
As this function is only ever used for top-level CSV files (i.e. the ones which actually define the IDs for a given type), we use an ordered map to maintain the order in the input files.