fn set_dangerous_model_options_flag(enabled: bool)Expand description
Set the global flag indicating whether potentially dangerous model options are enabled.
Can only be called once; subsequent calls will panic (except in tests, where it can be called multiple times so long as the value is the same).