pub struct DataWriter {
assets: Writer<File>,
asset_capacities: Writer<File>,
flows: Writer<File>,
prices: Writer<File>,
debug: Option<DebugDataWriter>,
}Expand description
An object for writing output data to file
Fields
assets: Writer<File>asset_capacities: Writer<File>flows: Writer<File>prices: Writer<File>debug: Option<DebugDataWriter>Implementations
Sourceimpl DataWriter
impl DataWriter
Sourcepub fn create(
output_path: &Path,
model_path: &Path,
save_debug_info: bool,
) -> Result<Self>
pub fn create( output_path: &Path, model_path: &Path, save_debug_info: bool, ) -> Result<Self>
Open CSV files to write output data to
Arguments
output_path- Folder where files will be savedmodel_path- Path to input modelsave_debug_info- Whether to include extra CSV files for debugging model
Sourcepub fn write_dispatch_debug_info(
&mut self,
milestone_year: u32,
run_description: &str,
solution: &Solution<'_>,
) -> Result<()>
pub fn write_dispatch_debug_info( &mut self, milestone_year: u32, run_description: &str, solution: &Solution<'_>, ) -> Result<()>
Write debug info about the dispatch optimisation
Sourcepub fn write_appraisal_debug_info(
&mut self,
milestone_year: u32,
run_description: &str,
appraisal_results: &[AppraisalOutput],
demand: &IndexMap<TimeSliceID, Flow>,
) -> Result<()>
pub fn write_appraisal_debug_info( &mut self, milestone_year: u32, run_description: &str, appraisal_results: &[AppraisalOutput], demand: &IndexMap<TimeSliceID, Flow>, ) -> Result<()>
Write debug info about the investment appraisal
Sourcepub fn write_assets<'a, I>(&mut self, assets: I) -> Result<()>
pub fn write_assets<'a, I>(&mut self, assets: I) -> Result<()>
Append newly commissioned asset definitions to the assets CSV file.
For divisible asset groups, a single row is emitted per group (using the parent asset’s metadata).
Sourcepub fn write_asset_capacities<'a, I>(
&mut self,
milestone_year: u32,
assets: I,
) -> Result<()>
pub fn write_asset_capacities<'a, I>( &mut self, milestone_year: u32, assets: I, ) -> Result<()>
Write asset capacities for the current milestone year to a CSV file.
This file is appended to on each invocation. For divisible asset groups, a single row is emitted per group with the total capacity.
Sourcepub fn write_flows(
&mut self,
milestone_year: u32,
flow_map: &FlowMap,
) -> Result<()>
pub fn write_flows( &mut self, milestone_year: u32, flow_map: &FlowMap, ) -> Result<()>
Write commodity flows to a CSV file
Sourcepub fn write_prices(
&mut self,
milestone_year: u32,
prices: &CommodityPrices,
) -> Result<()>
pub fn write_prices( &mut self, milestone_year: u32, prices: &CommodityPrices, ) -> Result<()>
Write commodity prices to a CSV file
Sourcepub fn set_debug_context(&mut self, context: String)
pub fn set_debug_context(&mut self, context: String)
Add context to the debug writer
Sourcepub fn clear_debug_context(&mut self)
pub fn clear_debug_context(&mut self)
Clear context from the debug writer