pub struct ProcessInvestmentConstraint {
pub addition_limit: Option<Capacity>,
}Expand description
A constraint imposed on investments in the process
Constraints apply to a specific milestone year, and have been pre-scaled from annual limits defined in the input data to account for the number of years since the previous milestone year.
Fields
addition_limit: Option<Capacity>Addition constraint: Limit an agent can invest in the process, shared according to the agent’s proportion of the process’s primary commodity demand
Implementations
Sourceimpl ProcessInvestmentConstraint
impl ProcessInvestmentConstraint
Sourcepub fn get_addition_limit(&self) -> Option<Capacity>
pub fn get_addition_limit(&self) -> Option<Capacity>
Calculate the effective addition limit
For now, this just returns addition_limit, but in the future when we add growth
limits and total capacity limits, this will have more complex logic which will depend on the
current total capacity.