pub struct ObjectiveCoefficients {
pub activity_coefficients: IndexMap<TimeSliceID, MoneyPerActivity>,
pub market_costs: IndexMap<TimeSliceID, MoneyPerActivity>,
}Expand description
Per-time-slice cost coefficients for an asset.
These coefficients are calculated according to the agent’s ObjectiveType and are used by the
investment appraisal routines. They comprise the activity coefficients (revenue minus operating
cost, derived from shadow prices) used in the appraisal optimisation, together with the market
costs (derived from market prices).
Fields
activity_coefficients: IndexMap<TimeSliceID, MoneyPerActivity>Cost per unit of activity in each time slice
market_costs: IndexMap<TimeSliceID, MoneyPerActivity>Market costs associated with asset for each time slice