pub fn add_activity_constraints(
problem: &mut RowProblem,
asset: &AssetRef,
activity_vars: &IndexMap<TimeSliceID, Col>,
time_slice_info: &TimeSliceInfo,
)Expand description
Adds activity constraints to the problem.
Constrains the activity variables to be within the asset’s activity limits.
The asset’s per-capacity activity limits are scaled by the asset’s capacity to give absolute bounds, and a single bounded constraint is added per time-slice selection covering the sum of activity in that selection.