pub fn add_demand_constraints(
problem: &mut RowProblem,
asset: &AssetRef,
commodity: &Commodity,
time_slice_info: &TimeSliceInfo,
demand: &DemandMap,
activity_vars: &IndexMap<TimeSliceID, Col>,
)Expand description
Adds demand constraints to the problem.
Constrains supply to be less than or equal to demand. One inequality constraint is added per time-slice selection at the commodity’s balance level, capping the sum of activity (scaled by flow coefficients) to the total demand for that selection.