fn get_parent_or_self(assets: &[AssetRef]) -> Vec<AssetRef>Expand description
Get the parent for each asset, if it has one, or itself.
Child assets are converted to their parents and non-divisible assets are returned as is. Each parent asset is returned only once.
If only a subset of a parent’s children are present in assets, a new parent asset representing
a portion of the total capacity will be created. This will have the same hash as the original
parent.