get_parent_or_self

Function get_parent_or_self 

fn get_parent_or_self(assets: &[AssetRef]) -> impl Iterator<Item = AssetRef>
Get the parent for each asset, if it has one, or itself.

Child assets are converted to their parents and non-divisible assets are returned as is. Each parent asset is returned only once.