pub struct Solution<'a> {
solution: Solution,
variables: VariableMap,
active_asset_var_idx: Range<usize>,
time_slice_info: &'a TimeSliceInfo,
constraint_keys: ConstraintKeys,
pub objective_value: Money,
}Expand description
The solution to the dispatch optimisation problem
Fields
solution: Solutionvariables: VariableMapactive_asset_var_idx: Range<usize>time_slice_info: &'a TimeSliceInfoconstraint_keys: ConstraintKeysobjective_value: MoneyThe objective value for the solution
Implementations
Sourceimpl Solution<'_>
impl Solution<'_>
Sourcepub fn create_flow_map(&self) -> FlowMap
pub fn create_flow_map(&self) -> FlowMap
Create a map of commodity flows for each asset’s coeffs at every time slice.
Note that this only includes commodity flows which relate to assets, so not every commodity in the simulation will necessarily be represented.
Sourcepub fn iter_activity(
&self,
) -> impl Iterator<Item = (&AssetRef, &TimeSliceID, Activity)>
pub fn iter_activity( &self, ) -> impl Iterator<Item = (&AssetRef, &TimeSliceID, Activity)>
Activity for each active asset
Sourcefn iter_activity_for_active(
&self,
) -> impl Iterator<Item = (&AssetRef, &TimeSliceID, Activity)>
fn iter_activity_for_active( &self, ) -> impl Iterator<Item = (&AssetRef, &TimeSliceID, Activity)>
Activity for each active asset
Sourcepub fn iter_commodity_balance_duals(
&self,
) -> impl Iterator<Item = (&CommodityID, &RegionID, &TimeSliceID, MoneyPerFlow)>
pub fn iter_commodity_balance_duals( &self, ) -> impl Iterator<Item = (&CommodityID, &RegionID, &TimeSliceID, MoneyPerFlow)>
Keys and dual values for commodity balance constraints.
Sourcepub fn iter_activity_duals(
&self,
) -> impl Iterator<Item = (&AssetRef, &TimeSliceID, MoneyPerActivity)>
pub fn iter_activity_duals( &self, ) -> impl Iterator<Item = (&AssetRef, &TimeSliceID, MoneyPerActivity)>
Keys and dual values for activity constraints.
Sourcefn zip_var_keys_with_output<'a, T: UnitType>(
&'a self,
variable_idx: &Range<usize>,
output: &'a [f64],
) -> impl Iterator<Item = (&'a AssetRef, &'a TimeSliceID, T)> + use<'a, T>
fn zip_var_keys_with_output<'a, T: UnitType>( &'a self, variable_idx: &Range<usize>, output: &'a [f64], ) -> impl Iterator<Item = (&'a AssetRef, &'a TimeSliceID, T)> + use<'a, T>
Zip a subset of keys in the variable map with a subset of the given output variable.
Arguments
variable_idx- The subset of variables to look atoutput- The output variable of interest